@@ -3,7 +3,7 @@
 use strict;
 use warnings;
 
-our $VERSION = '0.1';
+our $VERSION = '0.2';
 
 use Module::ScanDeps::Static;
 
@@ -11,9 +11,7 @@ __PACKAGE__->main();
 
 sub main {
 
-  Module::ScanDeps::Static->main;
-
-  exit 0;
-} ## end sub main
+  exit Module::ScanDeps::Static->main;
+}
 
 1;
